/**
 * $Id: Collections.java,v 1.3 2009/02/08 17:27:08 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 01.02.2009 by oliver (ob@oasd.de)
 */
package patterntesting.sample.dbc;

import static patterntesting.runtime.dbc.DbC.*;

import java.util.*;

/**
 * This is an example how the Collections utilties can be implemented using
 * DbC.
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 01.02.2009
 * @version $Revision: 1.3 $
 * @see java.util.Collections
 */
public class Collections {

    public static <T> int binarySearch(
            List<? extends Comparable<? super T>> list, T key) {
        require(isSorted(list), "list must be sorted");
        assert isSorted(list) : "list must be sorted";
        int found = java.util.Collections.binarySearch(list, key);
        ensure(found < list.size(), "found index out of bound");
        ensure(found >= -list.size(), "insertion point out of bound");
        return found;
    }
    
    @SuppressWarnings("unchecked")
    public static <T> boolean isSorted(
            List<? extends Comparable<? super T>> list) {
        if (list.isEmpty()) {
            return true;
        }
        Iterator<? extends Comparable<? super T>> iterator = list.iterator();
        Comparable<? super T> prev = iterator.next();
        while(iterator.hasNext()) {
            Comparable<? super T> next = iterator.next();
            if (prev.compareTo((T) next) > 0) {
                return false;
            }
            prev = next;
        }
        return true;
    }

}

/**
 * $Log: Collections.java,v $
 * Revision 1.3  2009/02/08 17:27:08  oboehm
 * replacing a require statement by assert (and vice versa)
 *
 * Revision 1.2  2009/02/03 20:08:30  oboehm
 * DbC support moved from patterntesting-check to patterntesting-rt
 *
 * Revision 1.1  2009/02/01 22:18:54  oboehm
 * Collections as example for DbC added
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-samples/src/main/java/patterntesting/sample/dbc/Collections.java,v $
 */
